api library

Classes

Device
DeviceAvailability
DeviceAvailabilityEnumTypeTransformer
Transformation class that can encode an instance of DeviceAvailability to String, and decode dynamic data back to DeviceAvailability.
DiscoveryApi
DiscoveryFilter
DiscoveryFilterEnumTypeTransformer
Transformation class that can encode an instance of DiscoveryFilter to String, and decode dynamic data back to DiscoveryFilter.

Functions

mapCastOfType<K, V>(dynamic map, String key) Map<K, V>?
Returns a valid Map<K, V> found at the specified Map key, null otherwise.
mapDateTime(dynamic map, String key, [String? pattern]) DateTime?
Returns a valid DateTime found at the specified Map key, null otherwise.
mapValueOfType<T>(dynamic map, String key) → T?
Returns a valid T value found at the specified Map key, null otherwise.
parameterToString(dynamic value) String
Format the given parameter object into a String.